#!/bin/bash
source helpers.sh

# The file where the results will be store

RESULT_FILE=results.txt

# You should put your builds into the 'builds' directory
TESTS_FILE=`ls builds`

# You can add more than one url
#TESTS_URL="file:///tmp/test-forms.html http://www.google.com http://bugzilla.mozilla.org"
TESTS_URL="file:///tmp/test-forms.html"

# Time wait when launching firefox from console to start testing
# 30 works on a n900
DELAY=4

# Number of times you want to repeat the xresponse test
repeat=5

rm $RESULT_FILE

for url in $TESTS_URL; do
  for test in $TESTS_FILE; do
    WININFO="800x480+0+0"
	  echo "Starting a new test for $test"
	  rm -Rf fennec/
    if [[ "$test" =~ ".bz2" ]]; then
      bunzip2 builds/${test}
    fi
	  tar -xf builds/${test/.bz2/}
	  echo "Waiting..."

    # Tweak that depending how you have done your build, usually a "fennec/fennec ${url}$"  is enough
	  LD_LIBRARY_PATH=/home/steakdepapillon/Devel/fennec/mobilebase/mobile/dist/bin/xulrunner fennec/fennec ${url} &

	  sleep ${DELAY}
  	echo "Fennec is launch with pid: $! - starting testing"

    # if we are doing a desktop test check the window position
    xwininfo=`type -P xwininfo`
    if [ -x ${xwininfo} ]; then
      WININFO=`xwininfo -name Fennec | grep geometry | cut -f4 -d" "`
    fi

	  echo "Testing $test" >> $RESULT_FILE

	  step=$((100/REPEAT))
    drag
    events="-d 180x460,180x160 -d 180x460,180x160 -d 180x460,180x160 -d 180x460,180x160 -d 180x160,180x460 -d 180x160,180x460 -d 180x160,180x460 -d 180x160,180x460"

    #dblclick XXX my implem is buggy but works
    #events="-l 6x260 -l 6x260 -l 6x260 -l 6x260 -l 6x260"
  	for i in `seq 1 ${REPEAT}`; do
		  xresponse/xresponse -m ${WININFO} -w 2  ${events} >> $RESULT_FILE
		  echo -ne "$((i*step)) %\r"
	  done;

	  kill -9 $!
  done;


  # I'm usually doing this part on desktop, so i'm not really sure how slow it is on device
  previous_total=-1
  total=-1

  while read line
  do
    if [[ "$line" =~ "Testing" ]]; then
      if [ $total -gt 0 ]; then
        echo "Total: $total"
      fi
      previous_total=$total
      total=0
      echo "$line"
    fi

    if [[ "$line" =~ "Total" ]]; then
      value=${line//[^0-9]/}
      total=$((value+total))
    fi
  done < $RESULT_FILE

  # Print the result
  percent=$(float_eval "($previous_total / $total) * 100 - 100")
  echo "Total: $total - ($percent%)"

done;
